from .base import Notification
from . import changelog
import jira
import logging


log = logging.getLogger(__name__)


class Jira(Notification):

    def __call__(self, url, filename, issue_prefix, status_id,
                 ignore_status_names, jira_username, jira_token, github_token):
        t = changelog.download_changelog(
            github_token, self.project, self.version, filename)
        issues = changelog.extract_issues(
            changelog.extract_version(t, self.version, self.previous_version),
            issue_prefix)

        api = jira.JIRA(server=url, basic_auth=(jira_username, jira_token))
        for issue in issues:
            issue = api.issue(issue)
            current = issue.fields.status.name
            if current in ignore_status_names:
                log.info('%s already has status %s', issue, current)
                continue
            log.info('Setting %s to %s', issue, status_id)
            api.transition_issue(issue, status_id)
